@@ -3,33 +3,24 @@
 <context>
     <name>GpxDocument</name>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="93"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="97"/>
         <source>The file </source>
         <translation>Файл </translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="93"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="97"/>
         <source> doesn&apos;t exist.</source>
         <translation> не существует.</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="135"/>
+        <location filename="../../gpxviewer/gpxdocument.py" line="161"/>
         <source>This file in not a valid GPX Viewer project file.</source>
         <translation>Этот файл не является файлом проекта GPX Viewer.</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="97"/>
-        <source>One of the files:
-
-</source>
-        <translation>Один из файлов:
-
-</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxdocument.py" line="97"/>
-        <source>has wrong number of valid waypoints. This file is likely to be damaged or changed from outside.</source>
-        <translation>содержит неправильное количество маршрутных точек. Вероятно, этот файл повреждён.</translation>
+        <location filename="../../gpxviewer/gpxdocument.py" line="102"/>
+        <source>One of the files has wrong number of valid waypoints or tracks. This file is likely to be damaged or changed from outside.</source>
+        <translation>Один из файлов содержит неправильное количество маршрутных точек или треков. Вероятно, этот файл повреждён или изменён извне.</translation>
     </message>
 </context>
 <context>
@@ -45,22 +36,177 @@
         <translation>Регулярное выражение</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="127"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="135"/>
         <source>Neglect previous distance</source>
         <translation>Не учитывать предыдущее расстояние</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="129"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="158"/>
         <source>Reset</source>
         <translation>Сброс</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="131"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="139"/>
         <source>Point style</source>
         <translation>Стиль точек</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="173"/>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="225"/>
+        <source>GPX Viewer Help</source>
+        <translation>Справка GPX Viewer</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="196"/>
+        <source>Version</source>
+        <translation>Версия</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="197"/>
+        <source>Using</source>
+        <translation>Используется</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="201"/>
+        <source>License:</source>
+        <translation>Лицензия:</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="202"/>
+        <source>About GPX Viewer</source>
+        <translation>О GPX Viewer</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="430"/>
+        <source>Distance Profile</source>
+        <translation>Профиль по расстоянию</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="451"/>
+        <source>Time Profile</source>
+        <translation>Профиль по времени</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="331"/>
+        <source>Open GPX file</source>
+        <translation>Открыть GPX файл</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="362"/>
+        <source>Open project file</source>
+        <translation>Открыть файл проекта</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="379"/>
+        <source>Save project file as</source>
+        <translation>Сохранить файл проекта как</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="127"/>
+        <source>Skip points</source>
+        <translation>Пропустить точки</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="129"/>
+        <source>Points with markers</source>
+        <translation>Точки с маркерами</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="131"/>
+        <source>Points with captions and markers</source>
+        <translation>Точки с подписями и маркерами</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="133"/>
+        <source>Points with splitting lines</source>
+        <translation>Точки с разделительными линиями</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="107"/>
+        <source>Close GPX Viewer</source>
+        <translation>Зактыть GPX Viewer</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="352"/>
+        <source>There are unsaved changes. Do you want to save the project?</source>
+        <translation>Есть несохранённые изменения. Вы хотите сохранить проект?</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="318"/>
+        <source>Load GPX file</source>
+        <translation>Загрузить GPX файл</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="352"/>
+        <source>Open GPX Viewer project</source>
+        <translation>Открыть проект GPX Viewer</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="344"/>
+        <source>GPX XML (*.gpx);;All files (*)</source>
+        <translation>GPX XML (*.gpx);;Все файлы (*.*)</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="422"/>
+        <source>File read error</source>
+        <translation>Ошибка чтения файла</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="379"/>
+        <source>GPX Viewer Projects (*.gpxv);;All files (*)</source>
+        <translation>Проекты GPX Viewer (*.gpxv);;Все файлы (*.*)</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="403"/>
+        <source>Multiple GPX files</source>
+        <translation>Несколько GPX файлов</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="344"/>
+        <source>Save GPX file as</source>
+        <translation>Сохранить GPX файл как</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="458"/>
+        <source>Not enouph points.</source>
+        <translation>Недостаточно точек.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="341"/>
+        <source>The GPX file will be empty.</source>
+        <translation>GPX файл будет пуст.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="392"/>
+        <source>The project is empty.</source>
+        <translation>Проект пуст.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="392"/>
+        <source>Save error</source>
+        <translation>Ошибка сохранения</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="448"/>
+        <source>Plot error</source>
+        <translation>Ошибка отрисовки</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="458"/>
+        <source>Statistics error</source>
+        <translation>Ошибка расчёта статистики</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="156"/>
+        <source>Skip tracks</source>
+        <translation>Пропустить треки</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="448"/>
+        <source>Not enouph points or tracks.</source>
+        <translation>Недостаточно точек или треков.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmainwindow.py" line="205"/>
         <source>Notation:&lt;br&gt;
                            &lt;font color=red&gt;Red&lt;/font&gt; - skipped points&lt;br&gt;
                            &lt;font color=blue&gt;Blue&lt;/font&gt; - marked points&lt;br&gt;
@@ -71,7 +217,15 @@
                            Useful shortcuts:&lt;br&gt;
                            Ctrl+C - Copy points to clipboard&lt;br&gt;
                            Ctrl+P - Show distance profile&lt;br&gt;
-                           Ctrl+T - Show time profile</source>
+                           Ctrl+T - Show time profile&lt;br&gt;
+                           Ctrl+I - Show statistics&lt;br&gt;
+                           &lt;br&gt;
+                           Several cases are possible when plotting a profile:
+                           &lt;ul&gt;
+                           &lt;li&gt;All non-skipped points have timestamps: points and tracks with timestamps are taken into account&lt;/li&gt;
+                           &lt;li&gt;There are points without timestamps: only points are considered, tracks are skipped&lt;/li&gt;
+                           &lt;li&gt;There are no points: all non-skipped tracks are taken into account&lt;/li&gt;
+                           &lt;/ul&gt;</source>
         <translation>Обозначения:&lt;br&gt;
                            &lt;font color=red&gt;Красный&lt;/font&gt; - пропущенные точки&lt;br&gt;
                            &lt;font color=blue&gt;Синий&lt;/font&gt; - точки с маркерами&lt;br&gt;
@@ -82,357 +236,192 @@
                            Комбинации клавиш:&lt;br&gt;
                            Ctrl+C - Копировать точки в буфер обмена&lt;br&gt;
                            Ctrl+P - Показать профиль по расстоянию&lt;br&gt;
-                           Ctrl+T - Показать профиль по времени </translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="185"/>
-        <source>GPX Viewer Help</source>
-        <translation>Справка GPX Viewer</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="164"/>
-        <source>Version</source>
-        <translation>Версия</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="165"/>
-        <source>Using</source>
-        <translation>Используется</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="169"/>
-        <source>License:</source>
-        <translation>Лицензия:</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="170"/>
-        <source>About GPX Viewer</source>
-        <translation>О GPX Viewer</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="385"/>
-        <source>Distance Profile</source>
-        <translation>Профиль по расстоянию</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="401"/>
-        <source>Time Profile</source>
-        <translation>Профиль по времени</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="285"/>
-        <source>Open GPX file</source>
-        <translation>Открыть GPX файл</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="313"/>
-        <source>Open project file</source>
-        <translation>Открыть файл проекта</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="329"/>
-        <source>Save project file as</source>
-        <translation>Сохранить файл проекта как</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="119"/>
-        <source>Skip points</source>
-        <translation>Пропустить точки</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="121"/>
-        <source>Points with markers</source>
-        <translation>Точки с маркерами</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="123"/>
-        <source>Points with captions and markers</source>
-        <translation>Точки с подписями и маркерами</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="125"/>
-        <source>Points with splitting lines</source>
-        <translation>Точки с разделительными линиями</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="100"/>
-        <source>Close GPX Viewer</source>
-        <translation>Зактыть GPX Viewer</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="303"/>
-        <source>There are unsaved changes. Do you want to save the project?</source>
-        <translation>Есть несохранённые изменения. Вы хотите сохранить проект?</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="270"/>
-        <source>Load GPX file</source>
-        <translation>Загрузить GPX файл</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="303"/>
-        <source>Open GPX Viewer project</source>
-        <translation>Открыть проект GPX Viewer</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="295"/>
-        <source>GPX XML (*.gpx);;All files (*)</source>
-        <translation>GPX XML (*.gpx);;Все файлы (*.*)</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="372"/>
-        <source>File read error</source>
-        <translation>Ошибка чтения файла</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="329"/>
-        <source>GPX Viewer Projects (*.gpxv);;All files (*)</source>
-        <translation>Проекты GPX Viewer (*.gpxv);;Все файлы (*.*)</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="354"/>
-        <source>Multiple GPX files</source>
-        <translation>Несколько GPX файлов</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="382"/>
-        <source>Not enouph points with distance.</source>
-        <translation>Недостаточно точек с расстоянием.</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="398"/>
-        <source>Not enouph points with timestamps.</source>
-        <translation>Недостаточно точек с отметками времени.</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="295"/>
-        <source>Save GPX file as</source>
-        <translation>Сохранить GPX файл как</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="408"/>
-        <source>Not enouph points.</source>
-        <translation>Недостаточно точек.</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="292"/>
-        <source>The GPX file will be empty.</source>
-        <translation>GPX файл будет пуст.</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="342"/>
-        <source>The project is empty.</source>
-        <translation>Проект пуст.</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="342"/>
-        <source>Save error</source>
-        <translation>Ошибка сохранения</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="398"/>
-        <source>Plot error</source>
-        <translation>Ошибка отрисовки</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmainwindow.py" line="408"/>
-        <source>Statistics error</source>
-        <translation>Ошибка расчёта статистики</translation>
+                           Ctrl+T - Показать профиль по времени &lt;br&gt;
+                           Ctrl+I - Показать статистику&lt;br&gt;
+                           &lt;br&gt;
+                           При рисовании профиля возможно несколько случаев:
+                           &lt;ul&gt;
+                           &lt;li&gt;Все непропущенные точки имеют отметки времени: учитываются точки и треки с отметками времени&lt;/li&gt;
+                           &lt;li&gt;Есть точки без отметок времени: учитываются только точки, треки пропускаются&lt;/li&gt;
+                           &lt;li&gt;Нет точек: учитываются все непропущенные треки&lt;/li&gt;
+                           &lt;/ul&gt;</translation>
     </message>
 </context>
 <context>
-    <name>GpxModel</name>
+    <name>GpxParser</name>
     <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
-        <source>Name</source>
-        <translation>Название</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
-        <source>Latitude</source>
-        <translation>Широта</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
-        <source>Longitude</source>
-        <translation>Долгота</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="42"/>
-        <source>Altitude</source>
-        <translation>Высота</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
-        <source>Distance</source>
-        <translation>Расстояние</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
-        <source>Time</source>
-        <translation>Время</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
-        <source>Time difference</source>
-        <translation>Разница во времени</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
-        <source>Time in days</source>
-        <translation>Время в днях</translation>
-    </message>
-    <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="157"/>
+        <location filename="../../gpxviewer/gpxmodel.py" line="221"/>
         <source> is an invalid GPX file.</source>
         <translation> повреждённый GPX файл.</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="207"/>
+        <location filename="../../gpxviewer/gpxmodel.py" line="270"/>
         <source>Waypoint </source>
         <translation>Маршрутная точка </translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="207"/>
+        <location filename="../../gpxviewer/gpxmodel.py" line="329"/>
+        <source>Track </source>
+        <translation>Трек </translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="270"/>
         <source>is invalid and will be skipped.</source>
+        <comment>Waypoint</comment>
         <translation>повреждена и будет пропущена.</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/gpxmodel.py" line="165"/>
-        <source>GPX file </source>
-        <translation>GPX файл </translation>
+        <location filename="../../gpxviewer/gpxmodel.py" line="329"/>
+        <source>is invalid and will be skipped.</source>
+        <comment>Track</comment>
+        <translation>повреждён и будет пропущен.</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="329"/>
+        <source>File read error</source>
+        <translation>Ошибка чтения файла</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="169"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="184"/>
         <source>&amp;Help</source>
         <translation>&amp;Справка</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="171"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="186"/>
         <source>&amp;Quit</source>
         <translation>&amp;Выход</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="172"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="187"/>
         <source>&amp;Open project</source>
         <translation>&amp;Открыть проект</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="173"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="188"/>
         <source>&amp;About Qt</source>
         <translation>&amp;О Qt</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="174"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="189"/>
         <source>&amp;Save project</source>
         <translation>&amp;Сохранить проект</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="175"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="190"/>
         <source>Save project &amp;as...</source>
         <translation>Сохранить проект &amp;как...</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="176"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="191"/>
         <source>&amp;Load GPX file</source>
         <translation>&amp;Загрузить GPX файл</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="180"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="195"/>
         <source>&amp;Show skipped</source>
         <translation>&amp;Показывать пропущенные</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="181"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="196"/>
         <source>Show &amp;marked</source>
         <translation>Показывать &amp;маркированные</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="182"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="197"/>
         <source>Show &amp;captioned</source>
         <translation>Показывать &amp;подписанные</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="183"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="198"/>
         <source>Show &amp;other</source>
         <translation>Показывать &amp;остальные</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="168"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="183"/>
         <source>&amp;File</source>
         <translation>&amp;Файл</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="170"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="185"/>
         <source>F&amp;ilter</source>
         <translation>Ф&amp;ильтр</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="177"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="192"/>
         <source>&amp;Distance profile</source>
         <translation>&amp;Профиль по расстоянию</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="178"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="193"/>
         <source>&amp;Time profile</source>
         <translation>Профиль по &amp;времени</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="179"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="194"/>
         <source>Profile &amp;style</source>
         <translation>&amp;Стиль профиля</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="184"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="199"/>
         <source>GPX Viewer &amp;Help</source>
         <translation>&amp;Справка GPX Viewer</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="185"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="200"/>
         <source>About &amp;GPX Viewer</source>
         <translation>О &amp;GPX Viewer</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="167"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="181"/>
         <source>Waypoints</source>
         <translation>Маршрутные точки</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="186"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="201"/>
         <source>&amp;New project</source>
         <translation>&amp;Новый проект</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="187"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="202"/>
         <source>&amp;Statistics</source>
         <translation>&amp;Статистика</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/ui_mainwindow.py" line="188"/>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="203"/>
         <source>Save &amp;GPX file as...</source>
         <translation>Сохранить &amp;GPX файл как...</translation>
     </message>
+    <message>
+        <location filename="../../gpxviewer/ui_mainwindow.py" line="182"/>
+        <source>Tracks</source>
+        <translation>Треки</translation>
+    </message>
 </context>
 <context>
     <name>PlotCanvas</name>
     <message>
-        <location filename="../../gpxviewer/plotcanvas.py" line="56"/>
+        <location filename="../../gpxviewer/plotcanvas.py" line="73"/>
         <source>Distance with coefficient 1.2 (km)</source>
         <translation>Расстояние с горным коэффициентом (км)</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/plotcanvas.py" line="58"/>
+        <location filename="../../gpxviewer/plotcanvas.py" line="76"/>
         <source>Time (days)</source>
         <translation>Время (дни)</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/plotcanvas.py" line="59"/>
+        <location filename="../../gpxviewer/plotcanvas.py" line="79"/>
         <source>Altitude (m)</source>
         <translation>Высота (м)</translation>
     </message>
+    <message>
+        <location filename="../../gpxviewer/plotcanvas.py" line="78"/>
+        <source>Time (hours)</source>
+        <translation>Время (часы)</translation>
+    </message>
 </context>
 <context>
     <name>PlotWindow</name>
@@ -452,12 +441,12 @@
         <translation>Размер для экспорта:</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/plotviewer.py" line="81"/>
+        <location filename="../../gpxviewer/plotviewer.py" line="82"/>
         <source>Export profile of the current size</source>
         <translation>Экспортировать профиль текущего размера</translation>
     </message>
     <message>
-        <location filename="../../gpxviewer/plotviewer.py" line="87"/>
+        <location filename="../../gpxviewer/plotviewer.py" line="88"/>
         <source>Export profile of the selected size</source>
         <translation>Экспортировать профиль выбранного размера</translation>
     </message>
@@ -507,22 +496,22 @@
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="47"/>
         <source>Tri down</source>
-        <translation type="unfinished"></translation>
+        <translation>Трилистник вниз</translation>
     </message>
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="48"/>
         <source>Tri up</source>
-        <translation type="unfinished"></translation>
+        <translation>Трилистник вверх</translation>
     </message>
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="49"/>
         <source>Tri left</source>
-        <translation type="unfinished"></translation>
+        <translation>Трилистник влево</translation>
     </message>
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="50"/>
         <source>Tri right</source>
-        <translation type="unfinished"></translation>
+        <translation>Трилистник вправо</translation>
     </message>
     <message>
         <location filename="../../gpxviewer/pointconfigdialog.py" line="51"/>
@@ -653,6 +642,82 @@
         <translation>Регулярное выражение</translation>
     </message>
 </context>
+<context>
+    <name>TrkModel</name>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="154"/>
+        <source>Name</source>
+        <translation>Название</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="154"/>
+        <source>Length</source>
+        <translation>Длина</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="154"/>
+        <source>Time</source>
+        <translation>Время</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="154"/>
+        <source>Duration</source>
+        <translation>Продолжительность</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="154"/>
+        <source>Segments</source>
+        <translation>Сегменты</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="154"/>
+        <source>Points</source>
+        <translation>Точки</translation>
+    </message>
+</context>
+<context>
+    <name>WptModel</name>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
+        <source>Name</source>
+        <translation>Название</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
+        <source>Latitude</source>
+        <translation>Широта</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
+        <source>Longitude</source>
+        <translation>Долгота</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="43"/>
+        <source>Altitude</source>
+        <translation>Высота</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="44"/>
+        <source>Distance</source>
+        <translation>Расстояние</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="44"/>
+        <source>Time</source>
+        <translation>Время</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="44"/>
+        <source>Time difference</source>
+        <translation>Разница во времени</translation>
+    </message>
+    <message>
+        <location filename="../../gpxviewer/gpxmodel.py" line="44"/>
+        <source>Time in days</source>
+        <translation>Время в днях</translation>
+    </message>
+</context>
 <context>
     <name>pointConfigDialog</name>
     <message>
